@@ -16,6 +16,8 @@ describe 'mistral::db::postgresql' do
         req_params
       end
 
+      it { is_expected.to contain_class('mistral::deps') }
+
       it { is_expected.to contain_openstacklib__db__postgresql('mistral').with(
         :user       => 'mistral',
         :password   => 'mistralpass',
@@ -38,7 +40,10 @@ describe 'mistral::db::postgresql' do
         }))
       end
 
-      it_configures 'mistral::db::postgresql'
+      # TODO(tkajinam): Remove this once puppet-postgresql supports CentOS 9
+      unless facts[:osfamily] == 'RedHat' and facts[:operatingsystemmajrelease].to_i >= 9
+        it_configures 'mistral::db::postgresql'
+      end
     end
   end
 
